@@ -170,6 +170,33 @@ return(*this);
 }
 
 
+#ifdef Streams
+
+#ifndef IOSTREAM_H_ONLY
+ using namespace std;
+#endif
+
+ostream &operator<<(ostream &xout, const doublelist & d)
+{
+int i;
+const char *s1, *s2;
+
+  xout << '{';
+  for(i=0; i<length(d); i++)
+	{
+        s1 = d.Member(i,0);
+        s2 = d.Member(i,1);
+	if(i>0) xout<<',';
+	xout << "{\"" << (s1==NULL?"NULL":s1) << "\",\""
+                      << (s2==NULL?"NULL":s2) << "\"}";
+	}
+return xout << '}';
+}
+
+#endif
+
+
+
 #if 0
 void main(void)
 {
