@@ -1,5 +1,5 @@
 /***************************************************
-* unit:    sets           release 0.9              *
+* unit:    sets           release 0.10             *
 * purpose: general manipulation with binary arrays *
 * Licency: GPL or LGPL                             *
 * Copyright: (c) 1998-2021 Jaroslav Fojtik         *
@@ -110,6 +110,7 @@ public:
             };
 
 char *set2str(char *str,const set &s);
+temp_set str2set(const char *str);
 
 
 //Internal speedup class - do not use it unless you know what you are doing!
@@ -138,10 +139,14 @@ inline set &set::operator^=(const set & s2)     {return *this=*this^s2;}
 
 
 #ifdef Streams
-#include <iostream.h>
-
-ostream &operator<<(ostream &xout, const set &s);
-//istream &operator>>(istream &, string &);
+ #ifdef IOSTREAM_H_ONLY
+  #include<iostream.h>
+  ostream &operator<<(ostream & xout, const stack & s);
+ #else
+  #include<iostream>
+  std::ostream &operator<<(std::ostream &xout, const set &s);
+  //istream &operator>>(istream &, set &l);
+ #endif
 #endif
 
 
