@@ -1,17 +1,14 @@
 /****************************************************
-* unit:    sets           release 0.9               *
+* unit:    sets           release 0.10              *
 * purpose: general manipulation with binary arrays  *
 * Licency: GPL or LGPL                              *
-* Copyright: (c) 1998-2021 Jaroslav Fojtik          *
+* Copyright: (c) 1998-2023 Jaroslav Fojtik          *
 *****************************************************/
 #include <stdlib.h>
 #include <limits.h>
 #include <string.h>
 #include <ctype.h>
 #include <stdio.h>
-#ifdef Streams
- #include <iostream.h>
-#endif
 
 #include "typedfs.h"
 #include <sets.h>
@@ -682,7 +679,7 @@ return(str);
 }
 
 
-/*This procedure converts set to the string inside given buffer*/
+/**This procedure converts set to the string inside given buffer*/
 char *set2str(char *str,const set &s)
 {
 int i,Last,num;
@@ -842,6 +839,11 @@ return(ret);
 
 
 #ifdef Streams
+
+#ifndef IOSTREAM_H_ONLY
+ using namespace std;
+#endif
+
 ostream &operator<<(ostream & xout, const set &s)
 {
 char str[200];		//!!!!Opravit, staticky buffer je docela spatny
