@@ -58,12 +58,9 @@ if(Name==NULL) return;
 if(*Name==0) return;
 if(position>=Allocated)
 	{
-	if( (characters=(char **)realloc(characters,sizeof(char **)*(position+1)))==NULL)
-		{
-NoMemory:	puts("Fatal: Memory exhausted");
-//		return;
-		exit(-1);
-		}
+        char ** const NewChars = (char **)realloc(characters,sizeof(char **)*(position+1));
+	if(NewChars==NULL) goto NoMemory;
+        characters = NewChars;
 	do {
 	   characters[Allocated++] = NULL;
 	   } while(position>=Allocated);
@@ -80,7 +77,13 @@ if(characters[position]!=NULL)
 	characters[position] = NULL;
 	}
 
-if( (characters[position]=strdup(Name))==NULL ) goto NoMemory;
+if( (characters[position]=strdup(Name))==NULL )
+  {
+NoMemory:
+    puts("Fatal: Memory exhausted");
+//  return;
+    exit(-1);
+  }
 if(position>=MaxUsed) MaxUsed=position+1;
 }
 
