@@ -6,6 +6,8 @@
  ******************************************************************************/
 #include "img_tool.h"
 
+#include "typedfs.h"
+
 
 void swab16(unsigned char *block, int PixelCount)
 {
@@ -72,6 +74,23 @@ char c;
 }
 
 
+/** Flip R and B and invert A coupounds in place.
+ * param[in]	Data	Pointer to data.
+ * param[in]	Size	Amount of RGB tripplets. */
+void RGBA32_BGRiA32(char *Data, int PixelCount)
+{
+char c;
+  while(PixelCount-->0)
+  {
+    c = Data[2];
+    Data[2] = *Data;
+    *Data = c;
+    Data[3] = ~Data[3];
+    Data += 4;
+  }
+}
+
+
 /** Flip R and B coupounds to the different buffer. */
 void RGB_BGR2(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount)
 {
@@ -133,11 +152,17 @@ void RGB_Gray(unsigned char *OutData, const unsigned char *InData, unsigned Pixe
  * @param[in]	size	Block size in Bytes. */
 void NotR(char *R, int size)	//R1:=not(R1)
 {
+  while(size>=4)
+  {
+    *(DWORD*)R = ~ *(DWORD*)R;
+    R += sizeof(DWORD*);
+    size -= 4;
+  }
   while(size-->0)
-    {
+  {
     *R = ~*R;
     R++;
-    }
+  }
 }
 
 
@@ -172,15 +197,15 @@ int X;
     else if(X<0) OutData[0]=0;
     else OutData[0] = X;
     X = (Y -102*U - 148*V) >> 8; // Y - 0.397*U - 0.58*V;
-    if(X>255) OutData[1]=255;                    
+    if(X>255) OutData[1]=255;
     else if(X<0) OutData[1]=0;
     else OutData[1] = X;
     X = (Y + 521*U) >> 8;	// Y + 2.034*U;
-    if(X>255) OutData[2]=255;                    
+    if(X>255) OutData[2]=255;
     else if(X<0) OutData[2]=0;
-    else OutData[2] = X;                    
+    else OutData[2] = X;
 
-    OutData += 3;    
+    OutData += 3;
     PixelCount -= 2;
   }
 }
@@ -195,35 +220,35 @@ int X;
     const int Y = 256 * *(yuyv++);
     const signed char U = *yuyv++ - 128;
     const int Y2 = 256 * *(yuyv++);
-    const signed char V = *yuyv++ - 128;    
+    const signed char V = *yuyv++ - 128;
 
     X = (Y + 291*V) >> 8;	// Y + 1.137*V;
     if(X>255) OutData[0]=255;
     else if(X<0) OutData[0]=0;
     else OutData[0] = X;
     X = (Y -102*U - 148*V) >> 8; // Y - 0.397*U - 0.58*V;
-    if(X>255) OutData[1]=255;                    
+    if(X>255) OutData[1]=255;
     else if(X<0) OutData[1]=0;
     else OutData[1] = X;
     X = (Y + 521*U) >> 8;	// Y + 2.034*U;
-    if(X>255) OutData[2]=255;                    
+    if(X>255) OutData[2]=255;
     else if(X<0) OutData[2]=0;
     else OutData[2] = X;
 
-    OutData += 3;    
+    OutData += 3;
 
     X = (Y2 + 291*V) >> 8;	// Y + 1.137*V;
     if(X>255) OutData[0]=255;
     else if(X<0) OutData[0]=0;
     else OutData[0] = X;
     X = (Y2 -102*U - 148*V) >> 8; // Y - 0.397*U - 0.58*V;
-    if(X>255) OutData[1]=255;                    
+    if(X>255) OutData[1]=255;
     else if(X<0) OutData[1]=0;
     else OutData[1] = X;
     X = (Y2 + 521*U) >> 8;	// Y + 2.034*U;
-    if(X>255) OutData[2]=255;                    
+    if(X>255) OutData[2]=255;
     else if(X<0) OutData[2]=0;
-    else OutData[2] = X;                    
+    else OutData[2] = X;
 
     OutData += 3;    
     PixelCount -= 2;
