@@ -93,7 +93,7 @@ static boolean ReadGenericProfile(j_decompress_ptr jpeg_info)
   size_t header_length=0, length;
   register size_t i;
   string profile_name;
-  unsigned char *profile;
+//  unsigned char *profile;
   int c, marker;
 
   if(jpeg_info->client_data==NULL) return TRUE;
