@@ -62,6 +62,32 @@ static int read_user_chunk_callback(png_struct *ping, png_unknown_chunkp chunk)
 }
 
 
+/// TODO: This function is not finished.
+Raster2DAbstract *LoadFragmentPNG(FILE *F)
+{
+//png_structp png_ptr;
+//png_infop info_ptr;
+
+  if(F==NULL) return NULL;
+/*
+  png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
+  if(!png_ptr) return NULL;
+
+  info_ptr = png_create_info_struct(png_ptr);
+  if(!info_ptr) goto FINISH;	// [read_png_file] png_create_info_struct failed
+
+  if(setjmp(png_jmpbuf(png_ptr))) goto FINISH;	// [read_png_file] Error during init_io
+
+  png_init_io(png_ptr, F);
+
+
+FINISH:
+  png_destroy_read_struct(&png_ptr, &info_ptr, png_infopp_NULL);
+*/
+  return NULL;
+}
+
+
 Image LoadPicturePNG(const char *Name)
 {
 Image Img;
