@@ -1,5 +1,5 @@
 /******************************************************************************
- * Unit:    raster            release 0.22                                    *
+ * Unit:    raster            release 0.23                                    *
  * Prototype declaration of separate classes. Normally this is not needed     *
  * to be included.                                                            *
  * licency:     GPL or LGPL                                                   *
@@ -348,6 +348,9 @@ public:	Raster1D_8BitRGBA(int InitSize1D)  {Allocate1D(InitSize1D);};
 
 	virtual DWORD GetValue1D(unsigned x) const;
 	virtual void SetValue1D(unsigned x, DWORD NewValue);
+	virtual void Get(unsigned x, RGBQuad *RGB) const;
+	void Get24BitRGB(void *Buffer24Bit) const;
+
 #ifdef _REENTRANT
         virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
 protected:
