@@ -1,5 +1,5 @@
 /*************************************************************
- * Unit:    raster            release 0.22                   *
+ * Unit:    raster            release 0.23                   *
  * Purpose: General manipulation n dimensional matrices      *
  *          n = 1, 2 and 3.			             *
  * Modul:   raster.cc                                        *
@@ -170,7 +170,7 @@ signed char shift;
     unsigned k = 0;
     while(shift >= 0)		// Needs to replicate lower bits.
     {
-      k |= 1 << shift;    
+      k |= 1 << shift;
       shift -= R1.GetPlanes();
     }
     for(i=0; i<maxi; i++)
@@ -1671,7 +1671,7 @@ DWORD val;
       {
       case 1: while(maxi-- > 0)	// convert from gray to RGB
 		{
-		val = R1.GetValue1D(i);
+		val = R1.GetValue1D(maxi);
 		R(maxi,val);
 		G(maxi,val);
 		B(maxi,val);
@@ -1683,7 +1683,7 @@ DWORD val;
 
       case 4: while(maxi-- > 0)		// convert from RGBA to RGB
 		{
-		val = R1.GetValue1D(i);
+		val = R1.GetValue1D(maxi);
 		R(maxi,val & 0xFF);
 		G(maxi,(val>>8)& 0xFF);
 		B(maxi,(val>>16)& 0xFF);
@@ -1696,7 +1696,7 @@ DWORD val;
     {
     while(maxi-- > 0)
        {
-       val = R1.GetValue1D(i);
+       val = R1.GetValue1D(maxi);
        val <<= shift;
        R(maxi,val);
        G(maxi,val);
@@ -1812,6 +1812,16 @@ void Raster1DAbstractRGB::Get(unsigned index, RGBQuad *RGB) const
 }
 
 
+void Raster1DAbstractRGBA::Get(unsigned index, RGBQuad *RGB) const
+{
+ if(RGB==NULL) return;
+ RGB->R = R(index);
+ RGB->G = G(index);
+ RGB->B = B(index);
+ RGB->O = A(index);
+}
+
+
 void Raster1DAbstractRGB::Set(unsigned index, const RGBQuad *RGB)
 {
  if(RGB==NULL) return;
@@ -1821,6 +1831,16 @@ void Raster1DAbstractRGB::Set(unsigned index, const RGBQuad *RGB)
 }
 
 
+void Raster1DAbstractRGBA::Set(unsigned index, const RGBQuad *RGB)
+{
+ if(RGB==NULL) return;
+ R(index, RGB->R);
+ G(index, RGB->G);
+ B(index, RGB->B);
+ A(index, RGB->O);
+}
+
+
 /* 8 bit planes for 3 channels R,G,B */
 
 DWORD Raster1D_8BitRGB::GetValue1D(unsigned x) const
@@ -1987,6 +2007,31 @@ void Raster1D_8BitRGBA::SetValue1D(unsigned x, DWORD NewValue)
 }
 
 
+void Raster1D_8BitRGBA::Get(unsigned x, RGBQuad *RGB) const
+{
+DWORD d = ((DWORD *)Data1D)[x];
+  RGB->R = d & 0xFF;
+  RGB->G = (d>>8) & 0xFF;
+  RGB->B = (d>>16) & 0xFF;
+  RGB->O = (d>>24) & 0xFF;
+}
+
+
+void Raster1D_8BitRGBA::Get24BitRGB(void *Buffer24Bit) const
+{
+BYTE *BBuffer24Bit = (BYTE *)Buffer24Bit;
+
+  if(Buffer24Bit==NULL) return;
+  for(unsigned x=0; x<Size1D; x++)
+  {
+    const DWORD d = ((DWORD *)Data1D)[x];
+    *BBuffer24Bit++ = d & 0xFF;
+    *BBuffer24Bit++ = (d>>8) & 0xFF;
+    *BBuffer24Bit++ = (d>>16) & 0xFF;
+  }
+}
+
+
 #ifdef _REENTRANT
 void Raster1D_8BitRGBA::PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const
 {
