@@ -1,16 +1,16 @@
 /***************************************************************************
- * Unit:    raster            release 0.22                                 *
+ * Unit:    raster            release 0.24                                 *
  * Purpose: Prototypes for general manipulation n dimensional matrices     *
  * Modul:   raster.cc                                                      *
  * Licency: GPL or LGPL                                                    *
- * Copyright: (c) 1998-2022 Jaroslav Fojtik                                *
+ * Copyright: (c) 1998-2023 Jaroslav Fojtik                                *
  ***************************************************************************/
 #ifndef __Rasters_h
 #define __Rasters_h
 
 #include "typedfs.h"
 
-#define RASTER_VERSION (0x100*0 | 22)
+#define RASTER_VERSION (0x100*0 | 24)
 
 #ifndef No_Memory
  #define No_Memory    0x1
@@ -180,7 +180,7 @@ protected:
         virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const {return(0);};
 	virtual double PTR_GetValue1Dd(const void *RAW_Data1D, unsigned x) const {return(PTR_GetValue1D(RAW_Data1D,x));};
 	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const = 0; // {AbstractError("RAW_SetValue1D");};
-	virtual void PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double NewValue) {PTR_SetValue1D(RAW_Data1D,x,NewValue);};
+	virtual void PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double NewValue) {PTR_SetValue1D(RAW_Data1D,x,(DWORD)NewValue);};
         virtual void PTR_Get(const void *RAW_Data1D, Raster1DAbstract &R1) const;
         virtual void PTR_Set(void *RAW_Data1D, const Raster1DAbstract &R1);
 #endif
@@ -233,6 +233,9 @@ public:
 
   virtual void Set(const Raster1DAbstract &R1);
 
+  virtual void Get(unsigned index, RGBQuad *RGB) const;
+  virtual void Set(unsigned index, const RGBQuad *RGB);
+
   unsigned R(unsigned x) const {return(GetValue1DRAW(4*x));}
   unsigned G(unsigned x) const {return(GetValue1DRAW(4*x+1));}
   unsigned B(unsigned x) const {return(GetValue1DRAW(4*x+2));}
@@ -400,8 +403,10 @@ void Flip3D(Raster3DAbstract *r3D);
 #endif
 
 /* ---------- Global class Image --------- */
+#include "stringa.h"
 
-#define RAS_IMG_VERSION (0x200 | 58)
+
+#define RAS_IMG_VERSION (0x200 | 61)
 
 /*Definition of errors while Loading/Saving File(s)*/
 #define ErrOK		  0
@@ -471,6 +476,34 @@ typedef enum
 
 class VectorImage;
 
+
+class PropertyItem
+{
+public:
+  PropertyItem(void) {Data=NULL;DataSize=0;UsageCount=0;}
+  virtual ~PropertyItem();
+
+  mutable short UsageCount;
+  void *Data;
+  unsigned DataSize;
+  string Name;
+};
+
+
+class PropertyList
+{
+public:
+  PropertyList(void) {pProperties=NULL;PropCount=0;};
+  ~PropertyList();
+
+  void AddProp(PropertyItem *NewProp);
+  bool isEmpty(void) const {return PropCount==0 || pProperties==NULL;}
+
+  int PropCount;
+  PropertyItem **pProperties;
+};
+
+
 class Image
 	{
 public: Raster2DAbstract *Raster;
@@ -478,6 +511,7 @@ public: Raster2DAbstract *Raster;
 	Image *Next;
 	float x,y,dx,dy,RotAngle;
 	VectorImage *VecImage;
+	PropertyList Properties;
 
 	Image(void): VecImage(NULL)  {RotAngle=x=y=dx=dy=0;Raster=NULL;Next=NULL;Palette=NULL;};
 	Image(const Image & I, bool AllFrames=true);
@@ -496,8 +530,9 @@ public: Raster2DAbstract *Raster;
 	void Create(unsigned SizeX, unsigned SizeY, int Planes);
 	void Erase(void);
 	void AttachRaster(Raster2DAbstract *NewRaster);
-        void AttachPalette(APalette *NewPalette);
-        void AttachVecImg(VectorImage *NewVecImg);
+	void AttachPalette(APalette *NewPalette);
+	void AttachVecImg(VectorImage *NewVecImg);
+	void AttachProperty(PropertyItem *NewProp);
 	};
 
 
