@@ -1,9 +1,9 @@
 /******************************************************************************
- * program:     rasimg library 0.22                                           *
+ * program:     rasimg library 0.23                                           *
  * function:    Object set for handling vector images.                        *
  * modul:       vec_image.cc                                                  *
  * licency:     GPL or LGPL                                                   *
- * Copyright: (c) 2018-2022 Jaroslav Fojtik                                   *
+ * Copyright: (c) 2018-2023 Jaroslav Fojtik                                   *
  ******************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
@@ -428,7 +428,7 @@ string str;
 
   if(PSS != NULL)
   {
-    vecPen::prepExport(PSS);    
+    vecPen::prepExport(PSS);
     vecBrush::prepExport(PSS);
     PS_Attr(str,PSS);
   }
@@ -486,7 +486,7 @@ string str;
 
   if(PSS != NULL)
   {
-    vecPen::prepExport(PSS);    
+    vecPen::prepExport(PSS);
     vecBrush::prepExport(PSS);
     PS_Attr(str,PSS);
   }
@@ -559,7 +559,7 @@ float x, y;
 
   if(PSS != NULL)
   {
-    vecBrush::prepExport(PSS);    
+    vecBrush::prepExport(PSS);
     vecPen::prepExport(PSS);
     PS_Attr(str,PSS);
   }
@@ -580,7 +580,7 @@ float x, y;
 
   if(BrushStyle!=FILL_NONE)
   {
-    FillObjectPS(LeftRect,RightRect,BottomRect,TopRect,str,PSS);    
+    FillObjectPS(LeftRect,RightRect,BottomRect,TopRect,str,PSS);
   }
   else
   {    
@@ -1008,9 +1008,9 @@ float *p = Points;
 	// There must be at least two points for the line.
   if(Points==NULL || CountPoints<=1) return temp_string();
 
-  if((CountPoints-1)%3 == 0) 
+  if((CountPoints-1)%3 == 0)
   {
-    ExtraStartup = true;    
+    ExtraStartup = true;
   }
   else
   {
@@ -1020,8 +1020,10 @@ float *p = Points;
   }
 
   if(PSS != NULL)
-  {    
-    vecPen::prepExport(PSS);    
+  {
+    vecPen::prepExport(PSS);
+    if(Filled && BrushStyle!=FILL_NONE)
+        vecBrush::prepExport(PSS);
     PS_Attr(str,PSS);
   }
   
@@ -1049,7 +1051,7 @@ float *p = Points;
   else
   {
     float xt_old = Points[4];		// Next control point.
-    float yt_old = Points[5];    
+    float yt_old = Points[5];
     for(p=Points+6; p<pEnd; p+=6)
     {
       str.cat_printf("\n%2.2f %2.2f %2.2f %2.2f %2.2f %2.2f curveto", xt_old,yt_old, *p, p[1], p[2], p[3]);
@@ -1124,7 +1126,7 @@ string str;
 
   if(PSS != NULL)
   {    
-    vecPen::prepExport(PSS);    
+    vecPen::prepExport(PSS);
     PS_Attr(str,PSS);
   }
 
@@ -1306,6 +1308,23 @@ VectorObject *IterObject = FirstObject;
   }
 }
 
+
+void VectorList::Swap(VectorList &VectList)
+{
+const int count = VectorObjects;
+  VectorObjects = VectList.VectorObjects;
+  VectList.VectorObjects = count;
+
+  VectorObject *pObj = FirstObject;
+  FirstObject = VectList.FirstObject;
+  VectList.FirstObject = pObj;
+
+  pObj = LastObject;
+  LastObject = VectList.LastObject;
+  VectList.LastObject = pObj;
+}
+
+
 /////////////////////////////////////////////////////////////
 
 
