@@ -488,7 +488,7 @@ char buffer[2];
 /// This is a state machine for detecting HTML files
 static int DetectHtml(FILE *text, FFormatDetect & iFFD)
 {
-int Status,CharNo=0,chr;
+int Status, CharNo=0, chr;
 
   iFFD.DocumentType="HTML";
   iFFD.Converter = iFFD.DocumentType;
@@ -508,8 +508,8 @@ int Status,CharNo=0,chr;
 		       if(chr=='<') {Status=1;break;}
 		       goto NoHTML;
 		case 1:if(chr=='!') {Status=11;break;}
-		       if(chr=='H') {Status=2;break;}
-		       if(chr=='M') {Status=7;break;}
+		       if(chr=='H') {Status=2;break;}	// HTML
+		       if(chr=='M') {Status=7;break;}	// META
 		       goto NoHTML;
 		case 2:if(chr=='T') {Status=3;break;}
 		       goto NoHTML;
@@ -529,12 +529,14 @@ int Status,CharNo=0,chr;
 			    return(1);	//HTML succesfully detected
 			    }
 		       break;
+
 		case 7:if(chr=='E') {Status=8;break;}
 		       goto NoHTML;
 		case 8:if(chr=='T') {Status=9;break;}
 		       goto NoHTML;
 		case 9:if(chr=='A') {Status=10;break;}
 		       goto NoHTML;
+
 		case 10:if(chr==' '){Status=11;break;}
 		       if(chr=='>') {Status=0;break;}
 		       goto NoHTML;
@@ -709,6 +711,80 @@ DWORD Magic1,Magic2;
 }
 
 
+/// This is a state machine for detecting DocBook files
+/// Docbook document might start with XML tag <book>
+/// or XML preamble folloved by <book> tag.
+/// DetectXML() does not detect <META><book>
+static int DetectDocbook(FILE *text, FFormatDetect & iFFD)
+{
+int Status, CharNo=0, chr;
+
+  iFFD.DocumentType = "docbook";
+  iFFD.Converter = iFFD.DocumentType;
+  iFFD.Extension = "DCB";
+  if(text==NULL) return(0);
+
+  Status=0;
+  fseek(text,0,SEEK_SET);
+  while(CharNo<MaxChar)
+	{
+	if( (chr=fgetc(text)) == EOF) goto NoDocBook;
+	chr=toupper(chr);
+	CharNo++;
+	switch(Status)
+		{
+		case 0:if(isspace(chr)) break;
+		       if(chr=='<') {Status=1;break;}
+		       goto NoDocBook;
+		case 1:if(chr=='!') {Status=101;break;}	// ?xml
+		       if(chr=='?') {Status=101;break;}	// ?xml
+		       if(chr=='B') {Status=2;break;}	// BOOK tag
+		       if(chr=='M') {Status=7;break;}	// META tag
+		       goto NoDocBook;
+
+		case 2:if(chr=='O') {Status=3;break;}
+		       goto NoDocBook;
+		case 3:if(chr=='O') {Status=4;break;}
+		       goto NoDocBook;
+		case 4:if(chr=='K') {Status=5;break;}
+		       goto NoDocBook;
+		case 5:if(chr=='>')
+			    {
+			    fseek(text,0,SEEK_SET);
+			    return(2);		//Docbook succesfully detected
+			    }
+		       Status=6;break;
+		case 6:if(chr=='>')
+			    {
+			    fseek(text,0,SEEK_SET);
+			    return(2);		//Docbook succesfully detected
+			    }
+		       break;
+
+		case 7:if(chr=='E') {Status=8;break;}
+		       goto NoDocBook;
+		case 8:if(chr=='T') {Status=9;break;}
+		       goto NoDocBook;
+		case 9:if(chr=='A') {Status=100;break;}
+		       goto NoDocBook;
+
+		case 100:if(chr==' '){Status=11;break;}	// Space or TAG close.
+		       if(chr=='>') {Status=0;break;}
+		       goto NoDocBook;
+
+		case 101:if(chr=='>') Status=0;
+		       break;
+		default:printf(_("Error: State automat failed at state %d\n"),Status);
+			Status=0;
+		}
+	}
+
+NoDocBook:
+  fseek(text,0,SEEK_SET);
+  return(0);
+}
+
+
 /** This procedure provides autodetection of XML format. */
 static int DetectXML(FILE *text, FFormatDetect & iFFD)
 {
@@ -760,12 +836,12 @@ static const char *DocType="!DOCTYPE";
 			   fseek(text,0,SEEK_SET);
 			   iFFD.DocumentType="abiword";
 			   iFFD.Converter=iFFD.DocumentType;
-                           iFFD.Extension = "abw";
+			   iFFD.Extension = "abw";
 			   return(2);
 			   }
 		       break;
 
-		case 20:if(chr=='o') {Status=21;break;}
+		case 20:if(chr=='o') {Status=21;break;}		//<book>  with XML preamble.
 		       goto XML_Detected;
 		case 21:if(chr=='o') {Status=22;break;}
 		       goto XML_Detected;
@@ -776,11 +852,19 @@ static const char *DocType="!DOCTYPE";
 			   fseek(text,0,SEEK_SET);
 			   iFFD.DocumentType = "docbook";
 			   iFFD.Converter = iFFD.DocumentType;
-                           iFFD.Extension = "DCB";
+			   iFFD.Extension = "DCB";
 			   return(3);
 			   }
 		       break;
 
+		case 30:if(chr=='o') {Status=31;break;}		//<book>  without XML preamble.
+		       goto NoXML;
+		case 31:if(chr=='o') {Status=32;break;}
+		       goto NoXML;
+		case 32:if(chr=='k') {Status=23;break;}
+		       goto NoXML;
+
+		case 100: if(chr=='b') {Status=30;break;}	// try to catch <book>.
 		default:if(Status>=100 && Status<strlen(XML)+100)
 			   {
 			   if(chr!=XML[Status-100]) goto NoXML;
@@ -850,6 +934,75 @@ char buffer[sizeof(PngSignature)];
   if(!memcmp(buffer,PngSignature,sizeof(PngSignature))) return 1;
   return(0);
 }
+
+
+/// This is a state machine for detecting SVG files
+static int DetectSvg(FILE *text, FFormatDetect & iFFD)
+{
+int Status, CharNo=0, chr;
+
+  iFFD.DocumentType="SVG";
+  iFFD.Converter = iFFD.DocumentType;
+  iFFD.Extension = "svg";
+  if(text==NULL) return(0);
+
+  Status=0;
+  fseek(text,0,SEEK_SET);
+  while(CharNo<MaxChar)
+	{
+	if( (chr=fgetc(text)) == EOF) goto NoSVG;
+	chr=toupper(chr);
+	CharNo++;
+	switch(Status)
+		{
+		case 0:if(isspace(chr)) break;
+		       if(chr=='<') {Status=1;break;}
+		       goto NoSVG;
+		case 1:if(chr=='!') {Status=101;break;}	// ?xml
+		       if(chr=='?') {Status=101;break;}	// ?xml
+		       if(chr=='S') {Status=2;break;}	// HTML tag
+		       if(chr=='M') {Status=7;break;}	// META tag
+		       goto NoSVG;
+
+		case 2:if(chr=='V') {Status=3;break;}
+		       goto NoSVG;
+		case 3:if(chr=='G') {Status=4;break;}
+		       goto NoSVG;
+		case 4:if(chr=='>')
+			    {
+			    fseek(text,0,SEEK_SET);
+			    return(2);		//SVG succesfully detected
+			    }
+		       Status=5;break;
+		case 5:if(chr=='>')
+			    {
+			    fseek(text,0,SEEK_SET);
+			    return(2);	//SVG succesfully detected
+			    }
+		       break;
+
+		case 7:if(chr=='E') {Status=8;break;}
+		       goto NoSVG;
+		case 8:if(chr=='T') {Status=9;break;}
+		       goto NoSVG;
+		case 9:if(chr=='A') {Status=100;break;}
+		       goto NoSVG;
+
+		case 100:if(chr==' '){Status=11;break;}	// Space or TAG close.
+		       if(chr=='>') {Status=0;break;}
+		       goto NoSVG;
+
+		case 101:if(chr=='>') Status=0;
+		       break;
+		default:printf(_("Error: State automat failed at state %d\n"),Status);
+			Status=0;
+		}
+	}
+
+NoSVG:
+  fseek(text,0,SEEK_SET);
+  return(0);
+}
 #endif
 
 
@@ -995,7 +1148,11 @@ long FilePos;
 	case 0x13:iFFD.DocumentType="Printer Resource file (.ALL)";break;
 	case 0x14:iFFD.DocumentType="Display Resource file (.DRS)";break;
 	case 0x15:iFFD.DocumentType="Overlay file";break;
-	case 0x16:iFFD.DocumentType="WordPerfect Graphics file";break;
+	case 0x16:iFFD.DocumentType="WordPerfect Graphics file";
+                  iFFD.Extension = iFFD.Converter = "WPG";
+                  iFFD.DocVersion=ver<<8;
+                  if(encryption!=0) fprintf(err,_(EncryptionWarning));
+                  break;
 	case 0x17:iFFD.DocumentType="Hyphenation code module";break;
 	case 0x18:iFFD.DocumentType="Hyphenation data module";break;
 	case 0x19:iFFD.DocumentType="Macro Resource File";break;
@@ -1023,7 +1180,26 @@ long FilePos;
 		  break;
 	case 0x2A:iFFD.DocumentType="Mouse driver for WP5.1";break;
 	case 0x2B:iFFD.DocumentType="Unix setup for WP5.0";break;
-	case 0x2C:iFFD.DocumentType="Macintosh WP2,3.x document";break;
+	case 0x2C:iFFD.DocumentType="Macintosh WP2,3.x document";
+                  switch(ver & 0xFF)
+                  {
+	            case 1: fprintf(err,_("\nWarning: Unknown MAC WP version 0x%x. Guessing WP%u.%u. EXPECT ERRORS!!! Please report."),ver,ver&0xFF,ver>>8);
+                    case 2: 	/*   version == MAC 2 -> WP 3.x  */
+                    case 3: 	/*   version == MAC 3 -> WP 3.x  */
+                    case 4: 	/*   version == MAC 4 -> WP MAC4.x  */
+	                   iFFD.DocVersion = (ver&0xFF)<<8 | ver>>8;
+	                   iFFD.DocumentStart = StartDoc;
+                           if(encryption!=0)
+		           {
+		             if(Verbosing>=1 && err!=NULL) 
+		             fprintf(err,_(EncryptionWarning));
+		             iFFD.Converter="WP3.x encrypted";
+		           }
+                           else
+		             iFFD.Converter="WP3.x";		//Convert_pass1_WP3;
+  	                   return ver & 0xFF;
+	          }
+                  break;
 	case 0x2D:iFFD.DocumentType="VAX file WP4.0 document";
 		  RunError(0x15,iFFD.DocumentType);
 		  break;
@@ -1035,36 +1211,6 @@ long FilePos;
         case 0x3A:iFFD.DocumentType="WP5.2 Far east";break;
 	}
 
-    if(filetype>>8 == 0x16)
-	{
-	iFFD.Extension = iFFD.Converter = "WPG";
-	iFFD.DocVersion=ver<<8;
-	if(encryption!=0) fprintf(err,_(EncryptionWarning));
-	}
-
-    if(filetype>>8 == 0x2C)
-	{
-        switch(ver & 0xFF)
-          {
-	  case 1: fprintf(err,_("\nWarning: Unknown MAC WP version 0x%x. Guessing WP%u.%u. EXPECT ERRORS!!! Please report."),ver,ver&0xFF,ver>>8);
-          case 2: 	/*   version == MAC 2 -> WP 3.x  */
-          case 3: 	/*   version == MAC 3 -> WP 3.x  */
-          case 4: 	/*   version == MAC 4 -> WP MAC4.x  */
-	     iFFD.DocVersion = (ver&0xFF)<<8 | ver>>8;
-	     iFFD.DocumentStart = StartDoc;
-             if(encryption!=0)
-		{
-		if(Verbosing>=1 && err!=NULL) 
-		    fprintf(err,_(EncryptionWarning));
-		iFFD.Converter="WP3.x encrypted";
-		}
-             else
-		iFFD.Converter="WP3.x";		//Convert_pass1_WP3;
-  	     return ver & 0xFF;
-	  }
-
-	}
-
     if(filetype==0x3A01)
         {
     	iFFD.DocumentStart = StartDoc;
@@ -1107,14 +1253,14 @@ long FilePos;
 	{
 	iFFD.Converter="WP??";
 	}*/
-    return 5;     /* it is a valid WP [5,6].x - document*/
+    return 5;		/* it is a valid WP [5,6].x - document*/
     }
 
-  if (id == 0x6161FFFE)		//This is a WP4.1 encrypted document
+  if(id == 0x6161FFFE)		//This is a WP4.1 encrypted document
 	{
 	iFFD.DocVersion=0x401;
 	iFFD.Converter = "WP4.x encrypted";  //Convert_pass1_WP4_encrypted;
-        iFFD.DocumentType = "WP4.x enc";
+	iFFD.DocumentType = "WP4.x enc";
 	return 4;
 	}
 
@@ -1223,7 +1369,11 @@ DetectXXX *Detect[] = {
 #endif
 		//++++Weak Tests++++
 	DetectBMP,
-	DetectUnicode,DetectPostScript,DetectHtml,DetectXML,
+	DetectUnicode,DetectPostScript,DetectHtml,
+#ifndef NO_IMG
+	DetectSvg,
+#endif
+	DetectXML, DetectDocbook,
 	DetectAccent,DetectRTF,DetectMTEF,DetectWord,DetectWinMetafile,
 	DetectWordPerfect4,DetectWordPerfect1,DetectT602
 	};
@@ -1711,16 +1861,23 @@ int p;
 
 	  if(!strncmp(name, "lang",4))
             {
+	    int lng;
+	    name += 4;
 	    if(*name=='-') name++;	    	// -no-lang-
 
-	    for(int lng=0; lng<sizeof(LangTable)/sizeof(LangItem); lng++)
+	    for(lng=0; lng<sizeof(LangTable)/sizeof(LangItem); lng++)
 	      {
               if(!strcmp(name,LangTable[lng].LangDesc))
 	        {
 	        LangTable[lng].UseLang = -1;
 	        break;
 	        }
-	      }               
+	      }
+            if(lng >= sizeof(LangTable)/sizeof(LangItem))
+              {
+                if(err!=NULL)
+                  fprintf(err,_("\nLanguage \"%s\" not present."),name);
+              }
             continue;
 	    }
 
@@ -1749,7 +1906,7 @@ int p;
 	if(!strcmp(name, "extract-WPG")||!strcmp(name, "extractWPG")||!strcmp(name, "extractwpg")) /*-no-extract-WPG*/
 		{
                 if(err!=NULL)
-                  fprintf(err,"\n-no-extract-WPG is deprecated, use -no-extract-images instead.");
+                  fprintf(err,_("\n-no-extract-WPG is deprecated, use -no-extract-images instead."));
 		SaveWPG = -1;
 		continue;
 		}
