@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"3.112"
-#define VersionDate	"31 Mar 2023"  /* day (space) month (space) full year */
+#define VersionWP2L	"3.113"
+#define VersionDate	"10 Jun 2023"  /* day (space) month (space) full year */
 
 
 /* Constants for a flag InputPS */
@@ -140,6 +140,8 @@ void Close_All_Attr(attribute & a, string & s, unsigned StartAttr=0);
 void Open_All_Attr(attribute & a, string & s);
 
 temp_string CutFileName(const char *FullFilename); //from wp2lfuti.cc
+
+extern string wpd_filename;
 #endif
 
 
